@@ -1,7 +1,7 @@
 from naomi.eeprom import NaomiEEPRom, NaomiEEPRomException
 from naomi.generic_patch import force_freeplay, force_no_attract_sound
 from naomi.rom import NaomiRom, NaomiRomRegionEnum, NaomiExecutable, NaomiRomSection, NaomiRomException
-from naomi.settings_patch import NaomiSettingsPatcher, NaomiSettingsPatcherException, get_default_trojan
+from naomi.settings_patch import NaomiSettingsPatcher, NaomiSettingsPatcherException, NaomiSettingsTypeEnum, get_default_trojan
 
 __all__ = [
     "NaomiRom",
@@ -13,6 +13,7 @@ __all__ = [
     "NaomiEEPRomException",
     "NaomiSettingsPatcher",
     "NaomiSettingsPatcherException",
+    "NaomiSettingsTypeEnum",
     "force_freeplay",
     "force_no_attract_sound",
     "get_default_trojan",
